# Installation

You can install the software with pip
```
python -m pip install mps-motion
```

Alternatively you can install it directly from Github
```
python3 -m pip install git+https://github.com/ComputationalPhysiology/mps_motion
```


## Docker
We also provide a pre-built docker image with all the dependencies and `mps-motion` installed. You pull this image using the command
```
docker pull ghcr.io/computationalphysiology/mps_motion:v0.2.11
```
